
---

## answer:q1

### Integer answer

1 / 1

### Correct answer

Your variable q1_answer has value 3.
 The expected answer is 1 because 21 = 5 * 3 + 1

0 / 3

---

## answer:q2

### Presence of docstring

1 / 1

### Correct answer

Your variable get_remainder has value <function get_remainder at 0x121791580>.
 Your function does not give the correct values

0 / 6
